Introduction
============

plone.app.jquery adds the `jquery`_ library to Plone.


Included is the jQuery migration plugin. You can install it by importing the
``development`` profile.

Versions
========

Version numbers of the package is the same as the jQuery library + packaging version.

For the latest available versions of this package, see our `PyPI page`_.

Note that this 1.11 version is not officially used by any Plone
version.  Use at your own risk/discretion.  Plone 4.3 uses 1.7.x.

Note that on Plone 5, this package is no longer used.

.. _`jquery`: http://jquery.com
.. _`PyPI page`: https://pypi.python.org/pypi/plone.app.jquery
